@@ -1,17 +1,21 @@
 /*
- * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
+ * Copyright 2012-2026 the original author or authors.
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
- * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
- * specific language governing permissions and limitations under the License.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * Copyright 2012-2025 the original author or authors.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 package org.assertj.core.internal;
 
+import static java.nio.file.Files.createSymbolicLink;
 import static org.assertj.core.testkit.TestData.someInfo;
 import static org.mockito.Mockito.mockingDetails;
 import static org.mockito.Mockito.reset;
@@ -24,6 +28,8 @@ import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.io.TempDir;
+import org.junit.platform.commons.function.Try;
+import org.opentest4j.TestAbortedException;
 
 /**
  * Base class for {@link Paths} tests.
@@ -68,4 +74,10 @@ public abstract class PathsBaseTest {
     reset(nioFilesWrapper, failures, diff, binaryDiff);
   }
 
+  // https://github.com/assertj/assertj/issues/3183
+  protected static Path tryToCreateSymbolicLink(Path link, Path target) {
+    return Try.call(() -> createSymbolicLink(link, target))
+              .getOrThrow(e -> new TestAbortedException("Failed to create symbolic link", e));
+  }
+
 }
